/*  -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 * 
 * This file is part of the GNOME Devtools Libraries.
 * 
 * Copyright (C) 1999-2000 Dave Camp <dave@helixcode.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.  
 */

#ifndef __GDL_H__
#define __GDL_H__

#include <gdl/gdl-tools.h>
#include <gdl/gdl-dock-object.h>
#include <gdl/gdl-dock-master.h>
#include <gdl/gdl-dock.h>
#include <gdl/gdl-dock-item.h>
#include <gdl/gdl-dock-layout.h>
#include <gdl/gdl-dock-paned.h>
#include <gdl/gdl-dock-notebook.h>
#include <gdl/gdl-dock-tablabel.h>
#include <gdl/gdl-recent.h>
#include <gdl/gdl-icons.h>
#include <gdl/gdl-combo-button.h>

#endif
